@@ -25,6 +25,10 @@ if os.path.exists(local_plugin_path):
 from teedoc_plugin_markdown_parser.parse_metadata import Meta_Parser
 from teedoc_plugin_markdown_parser.renderer import create_markdown_parser
 
+
+__version__ = "1.0.15"
+
+
 class Plugin(Plugin_Base):
     name = "teedoc-plugin-blog"
     desc = "markdown parser plugin for teedoc"
@@ -32,11 +36,12 @@ class Plugin(Plugin_Base):
         "parse_files": ["md"]
     }
 
-    def on_init(self, config, doc_src_path, site_config, logger = None):
+    def on_init(self, config, doc_src_path, site_config, logger = None, multiprocess = True, **kw_args):
         '''
             @config a dict object
             @logger teedoc.logger.Logger object
         '''
+        self.multiprocess = multiprocess
         self.logger = Fake_Logger() if not logger else logger
         self.doc_src_path = doc_src_path
         self.site_config = site_config
@@ -83,7 +88,7 @@ class Plugin(Plugin_Base):
         del self.md_parser
         del self.meta_parser
 
-    def on_parse_blog(self, files, new_config=None):
+    def on_parse_blog(self, files):
         # result, format must be this
         result = {
             "ok": False,
@@ -107,8 +112,14 @@ class Plugin(Plugin_Base):
                     is_blog_index = file.lower() == blog_index_file_path
                     if is_blog_index:
                         content += '\n<div id="blog_list"></div>'
-                    metadata, content_no_meta = self.meta_parser.parse_meta(content)
-                    html = self.md_parser(content_no_meta)
+                    if not self.multiprocess:
+                        md_parser = create_markdown_parser()
+                        meta_parser = Meta_Parser()
+                    else:
+                        md_parser = self.md_parser
+                        meta_parser = self.meta_parser
+                    metadata, content_no_meta = meta_parser.parse_meta(content)
+                    html = md_parser(content_no_meta)
                     if "<!-- more -->" in html:
                         brief = html[:html.find("<!-- more -->")].strip()
                     else:
@@ -171,7 +182,7 @@ class Plugin(Plugin_Base):
         result['ok'] = True
         return result
     
-    def on_add_html_header_items(self):
+    def on_add_html_header_items(self, type_name):
         items = []
         items.append('<meta name="blog-generator" content="teedoc-plugin-blog">')
         return items
@@ -267,7 +278,7 @@ class Plugin(Plugin_Base):
         self.files_to_copy = {}
         return res
 
-    def on_add_html_js_items(self):
+    def on_add_html_footer_js_items(self, type_name):
         for url in self.assets:
             html_js_items = ['<script src="{}"></script>'.format(url)]
         return html_js_items
